pype32.directories.ImageBoundForwarderRef

Package pype32 :: Module directories :: Class ImageBoundForwarderRef |
[hide private]
[frames] | no frames]

# Class ImageBoundForwarderRef

source code

    object --+
             |
          list --+
                 |
                ImageBoundForwarderRef

ImageBoundForwarderRef array object.

Instance Methods | [hide private]
new empty list |
__init__(self, shouldPack=True) This class is a wrapper over an array of `IMAGE_BOUND_FORWARDER_REF`. | source code
__str__(self) str(x) | source code
Inherited from `list`: `__add__`, `__contains__`, `__delitem__`, `__delslice__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__gt__`, `__iadd__`, `__imul__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__mul__`, `__ne__`, `__new__`, `__repr__`, `__reversed__`, `__rmul__`, `__setitem__`, `__setslice__`, `__sizeof__`, `append`, `count`, `extend`, `index`, `insert`, `pop`, `remove`, `reverse`, `sort` Inherited from `object`: `__delattr__`, `__format__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__subclasshook__`

Static Methods | [hide private]
ImageBoundForwarderRef |
parse(readDataInstance, numberOfEntries) Returns a ImageBoundForwarderRef array where every element is a ImageBoundForwarderRefEntry object. | source code

Class Variables | [hide private]
Inherited from `list`: `__hash__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, shouldPack=True) (Constructor) | source code
This class is a wrapper over an array of `IMAGE_BOUND_FORWARDER_REF`. Parameters: `shouldPack` (bool) - (Optional) If set to c{True}, the object will be packed. If set to `False`, the object won't be packed. Returns: new empty list Overrides: object.__init__

### __str__(self) (Informal representation operator) | source code
str(x) Overrides: object.__str__ (inherited documentation)

### parse(readDataInstance, numberOfEntries) Static Method | source code
Returns a ImageBoundForwarderRef array where every element is a ImageBoundForwarderRefEntry object. Parameters: `readDataInstance` (ReadData) - A ReadData object with the corresponding data to generate a new ImageBoundForwarderRef object. `numberOfEntries` (int) - The number of `IMAGE_BOUND_FORWARDER_REF` entries in the array. Returns: ImageBoundForwarderRef A new ImageBoundForwarderRef object. Raises: `DataLengthException` - If the ReadData instance has less data than `NumberOfEntries` * sizeof ImageBoundForwarderRefEntry.